@@ -10,20 +10,18 @@ XML::GrammarBase::Role::XSLT - a parameterized role for an XSLT converter.
 
 =head1 VERSION
 
-Version 0.0.1
+Version 0.0.2
 
 =cut
 
-use Moo::Role;
-
-use MooX 'late';
+use MooX::Role 'late';
 
 use XML::LibXML;
 use XML::LibXSLT;
 
 use autodie;
 
-our $VERSION = '0.0.1';
+our $VERSION = '0.0.2';
 
 with ('XML::GrammarBase::Role::RelaxNG');
 
